import Image from "next/image";

import { ArrowDown } from "lucide-react";

import { ProductFeatureBlogCard } from "@/components/shared/product-feature-blog-card";
import BlurFade from "@/components/ui/blur-fade";
import { Button } from "@/components/ui/button";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import {
	ProductDetailsBlogFeature,
	getProductDetailsBlogFeature,
} from "@/utils/get-fake-data";

interface ProductFeaturesBlogSectionProps {
	locale: Locale;
}

export default async function ProductFeaturesBlogSection({
	locale,
}: ProductFeaturesBlogSectionProps) {
	const data = await getProductDetailsBlogFeature();
	const isRTL = locale === "ar";

	// Helper function to chunk features array into groups of 3
	const featureGroups = data.features.reduce((groups, feature, index) => {
		const groupIndex = Math.floor(index / 3);
		if (!groups[groupIndex]) {
			groups[groupIndex] = [];
		}
		groups[groupIndex].push(feature);
		return groups;
	}, [] as ProductDetailsBlogFeature[][]);

	return (
		<section className="relative min-h-screen w-full px-4 py-16">
			<div className="mx-auto max-w-7xl">
				{featureGroups?.map((group, groupIndex) => (
					<div
						key={groupIndex}
						className={cn(
							"relative grid grid-cols-1 gap-6 md:grid-cols-2 lg:grid-cols-12",
							groupIndex > 0 && "mt-24"
						)}
					>
						{/* Header only appears in the first group */}
						{groupIndex === 0 && (
							<div className="lg:col-span-7 lg:col-start-1">
								<BlurFade direction="left" delay={0.25} inView>
									<Image
										src="/images/our-services/Feature_Title.png"
										alt="Feature Title"
										width={1000}
										height={1000}
										className="h-auto w-auto"
									/>
								</BlurFade>
								<p
									className={cn(
										"mt-6 text-4xl leading-[45px] text-custom-dark-veryDark",
										isRTL && "font-arabic text-right"
									)}
								>
									{data.description?.[locale]}
								</p>
								<p
									data-scroll
									data-scroll-speed={0.1}
									className={cn(
										"mt-6 text-justify text-base text-[#757575]",
										isRTL && "font-arabic text-right"
									)}
								>
									{data.description_2[locale]}
								</p>
								<Button className="mt-8 rounded-xl bg-custom-primary-accent px-6 py-4 text-white hover:bg-custom-primary">
									{locale === "ar" ? "أكتشف المزيد " : "Discover more"}
									<ArrowDown className="h-6 w-6" />
								</Button>
							</div>
						)}
						{/* Cards with dynamic positioning */}
						{group?.map((feature, index) => (
							<div
								key={feature.id}
								className={cn(
									"lg:col-span-4",
									// Position cards based on their index within the group
									index === 0 && "lg:col-start-9",
									index === 1 && "lg:col-start-5 lg:-mt-[50%]",
									index === 2 && "lg:col-start-1 lg:-mt-[50%]"
								)}
							>
								<ProductFeatureBlogCard
									index={index}
									feature={feature}
									locale={locale}
								/>
							</div>
						))}
					</div>
				))}
			</div>
		</section>
	);
}
